##################################################################################
######## SECTION 1: THIS SECTION DOWNLOADS ALL REPLICATION DATA ONTO A LOCAL FOLDER
##################################################################################

dir <- paste(getwd(), "/Chen_Replication_Code",sep="")
dir.create(dir)
print(paste("ALL REPLICATION CODE WILL BE DOWNLOADED TO THE FOLLOWING FOLDER:",dir))

##DOWNLOAD THE REPLICATION DATA FOR NON-COMPACT SIMULATIONS, IF NECESSARY
NonCompactFolder <- paste(dir, "/FL_Simulations_NonCompact",sep="")
FLdbffile <- paste(NonCompactFolder,"/FL.dbf",sep="")
if (!file.exists(FLdbffile)){
	NonCompactzipfile <- "http://www.umich.edu/~jowei/UnintentionalGerrymandering/FL_Simulations_NonCompact.zip"
	LocalNoncompactZipped <- paste(dir,"/FL_Simulations_NonCompact.zip",sep="")
	download.file(NonCompactzipfile, LocalNoncompactZipped )
	unzip(LocalNoncompactZipped, exdir=dir)
}


##DOWNLOAD THE REPLICATION DATA FOR COMPACT SIMULATIONS, IF NECESSARY
CompactFolder <- paste(dir, "/FL_Simulations_Compact",sep="")
FLdbffile <- paste(CompactFolder,"/FL.dbf",sep="")
if (!file.exists(FLdbffile)){
	Compactzipfile <- "http://www.umich.edu/~jowei/UnintentionalGerrymandering/FL_Simulations_Compact.zip"
	LocalCompactZipped <- paste(dir,"/FL_Simulations_Compact.zip",sep="")
	download.file(Compactzipfile, LocalCompactZipped )
	unzip(LocalCompactZipped, exdir=dir)
}

######## DOWNLOADING OF REPLICATION DATA ENDS HERE


#####################################################################
######## SECTION 2: NON-COMPACT DISTRICTING SIMULATIONS FOR FLORIDA
#####################################################################
library(maptools)
library(plotrix)
library(gpclib)
gpclibPermit()

library(foreign)


############### GET COMPACT PLAN
dist <- 25
st <- "FL"
districts <- dist
x <- readShapePoly(paste(CompactFolder,"/",st,districts,".shp",sep=""))
proj4string(x) <- "+proj=longlat +datum=WGS84"
plans <- dim(x)[2]-15 ##TOTAL NUMBER OF SIMULATED PLANS

x$mccainshare <- x$mccain / (x$mccain+x$obama)
x$cn <- 100*round(x$mccainshare,2)
x$cn[is.na(x$cn)] <- 0.50
d <- as.data.frame(x)

plan <- 12
print(paste(districts,plan))

##MAP THE DISTRICTING PLAN
test <- unionSpatialPolygons(x, d[,(13+plan)])

############### GET NONCOMPACT PLAN


xn <- readShapePoly(paste(NonCompactFolder,"/",st,districts,".shp",sep=""))
proj4string(xn) <- "+proj=longlat +datum=WGS84"
plans <- dim(xn)[2]-15 ##TOTAL NUMBER OF SIMULATED PLANS

xn$mccainshare <- xn$mccain / (xn$mccain+xn$obama)
xn$cn <- 100*round(xn$mccainshare,2)
xn$cn[is.na(x$cn)] <- 0.50
d <- as.data.frame(xn)

plan <- 2
print(paste(districts,plan))

##MAP THE DISTRICTING PLAN
testn <- unionSpatialPolygons(xn, d[,(13+plan)])

############### PLOT THEM TOGETHER


##postscript(paste(dir,"/Appendix_1_PlanExamples.eps",sep=""), width=9, height=4, horizontal=FALSE)

layout(   matrix(c(1,2), 1,2,byrow=TRUE), widths=c(1,1) )

par(mar=c(0,0,3,0))
plot(test, axes=FALSE, col=1:length(test), yaxt="n", border=0)
title("Example of a Compact Simulated \nCongressional Districting Plan (25 Districts)", cex.main=0.9)


par(mar=c(0,0,3,0))
plot(testn, axes=FALSE, col=1:length(testn), yaxt="n", border=0)
title("Example of a Non-Compact Simulated \nCongressional Districting Plan (25 Districts)", cex.main=0.9)

##dev.off()

