##################################################################################
######## SECTION 1: THIS SECTION DOWNLOADS ALL REPLICATION DATA ONTO A LOCAL FOLDER
##################################################################################

dir <- paste(getwd(), "/Chen_Replication_Code",sep="")
dir.create(dir)
print(paste("ALL REPLICATION CODE WILL BE DOWNLOADED TO THE FOLLOWING FOLDER:",dir))

##DOWNLOAD THE REPLICATION DATA FOR NON-COMPACT SIMULATIONS, IF NECESSARY
NonCompactFolder <- paste(dir, "/FL_Simulations_NonCompact",sep="")
FLdbffile <- paste(NonCompactFolder,"/FL.dbf",sep="")
if (!file.exists(FLdbffile)){
	NonCompactzipfile <- "http://www.umich.edu/~jowei/UnintentionalGerrymandering/FL_Simulations_NonCompact.zip"
	LocalNoncompactZipped <- paste(dir,"/FL_Simulations_NonCompact.zip",sep="")
	download.file(NonCompactzipfile, LocalNoncompactZipped )
	unzip(LocalNoncompactZipped, exdir=dir)
}


##DOWNLOAD THE REPLICATION DATA FOR COMPACT SIMULATIONS, IF NECESSARY
CompactFolder <- paste(dir, "/FL_Simulations_Compact",sep="")
FLdbffile <- paste(CompactFolder,"/FL.dbf",sep="")
if (!file.exists(FLdbffile)){
	Compactzipfile <- "http://www.umich.edu/~jowei/UnintentionalGerrymandering/FL_Simulations_Compact.zip"
	LocalCompactZipped <- paste(dir,"/FL_Simulations_Compact.zip",sep="")
	download.file(Compactzipfile, LocalCompactZipped )
	unzip(LocalCompactZipped, exdir=dir)
}

######## DOWNLOADING OF REPLICATION DATA ENDS HERE


#####################################################################
######## SECTION 2: NON-COMPACT DISTRICTING SIMULATIONS FOR FLORIDA
#####################################################################
library(foreign)
dists <- seq(1:200)
y <- as.data.frame(dists)
y$repshare <- NA
y$lo <- NA
y$hi <- NA

dbffile <- paste(NonCompactFolder,"/FL.dbf",sep="")
dbf <- read.dbf(dbffile)
swrepvote <- sum(dbf$mccain, na.rm=TRUE) / (sum(dbf$mccain, na.rm=TRUE) + sum(dbf$obama, na.rm=TRUE))
BushVoteShare <- swrepvote


for (i in dists){
print(i)

sharesfile <- paste(NonCompactFolder,"/",i,".txt",sep="")
if (file.exists(sharesfile) & i>1){
x <- read.table(sharesfile)[1:25,]
x1 <- x[,4:dim(x)[2]]

repseats <- apply(x1, 1, function(x) sum(x>BushVoteShare))
meds <- apply(x1, 1, function(x) median(x))

AvgRepSeats <- mean(repseats)
AvgRepSeatShare <- AvgRepSeats/i
NumberOfSimulations <- dim(x)[1]

y$repshare[i] <- AvgRepSeatShare
y$lo[i] <- min(repseats/i)
y$hi[i] <- max(repseats/i)

y$meds[i] <- mean(meds)
y$medlo[i] <- min(meds)
y$medhi[i] <- max(meds)

}
}

################################################################
######## SECTION 3: COMPACT DISTRICTING SIMULATIONS FOR FLORIDA
################################################################

z <- as.data.frame(dists)
z$repshare <- NA
z$lo <- NA
z$hi <- NA

dbffile <- paste(CompactFolder,"/FL.dbf",sep="")

dbf <- read.dbf(dbffile)
swrepvote <- sum(dbf$mccain, na.rm=TRUE) / (sum(dbf$mccain, na.rm=TRUE) + sum(dbf$obama, na.rm=TRUE))
BushVoteShare <- swrepvote


for (i in dists){
print(i)

sharesfile <- paste(CompactFolder,"/",i,".txt",sep="")
if (file.exists(sharesfile) & i>1){
x <- read.table(sharesfile)[1:25,]
x1 <- x[,4:dim(x)[2]]

repseats <- apply(x1, 1, function(x) sum(x>BushVoteShare))
meds <- apply(x1, 1, function(x) median(x))

AvgRepSeats <- mean(repseats)
AvgRepSeatShare <- AvgRepSeats/i
NumberOfSimulations <- dim(x)[1]

z$repshare[i] <- AvgRepSeatShare
z$lo[i] <- min(repseats/i)
z$hi[i] <- max(repseats/i)

z$meds[i] <- mean(meds)
z$medlo[i] <- min(meds)
z$medhi[i] <- max(meds)

}
}


######################################################################################
######## SECTION 4: CODE TO REPRODUCE FIGURE 4 (SIMULATED ELECTORAL BIAS IN FLORIDA)
######################################################################################

##THIS PRODUCES THE FIGURE WITH SIMULATED SEAT SHARES FOR COMPACT AND NON-COMPACT FLORIDA, 2 TO 200 SEATS

layout(   matrix(c(1,2), 1,2,byrow=TRUE), widths=c(1,1) )

par(mar=c(3.7,3.7,3,0.1))	
plot(repshare~dists  ,data=y[y$dists>=2 & y$dists<200,], type="p", ylim=c(0.15,0.85), cex.axis=0.75, pch=20, cex=0.5, ylab="",xlab="",main="",xaxt="n")	
for (i in dists){	
	color = "gray"
	ld <- 1
	if (i %in% c(25,40,120)){color <- "red"; ld <- 2}
	lines(c(i,i),c(y$lo[i], y$hi[i]), col=color, lwd=ld)
}	
lines(c(-100,1000), c(0.5,0.5), lty="dashed")	
title("Electoral Bias in Simulated Florida Districting Plans\n(Non-Compact District Simulation Procedure)",	
, ylab="Average Share of Simulated Districts Favoring Bush (Nov. 2000)"	
, xlab="Number of Districts in Simulated Districting Plan"	
, cex.main=0.75	
, cex.lab=0.75	
, mgp=c(1.9, 0.5, 0))	
axis(1, at=c(1,25,50,75,100,125,150,175,200), lab=c(1,25,50,75,100,125,150,175,200),	
mgp=c(1.8, 1, 0), cex.axis=0.75)	
points(repshare~dists  ,data=y[y$dists>=2 & y$dists<200,], type="p", pch=20, cex=0.5)	



par(mar=c(3.7,3.7,3,0.1))	
plot(repshare~dists  ,data=z[z$dists>=2 & z$dists<200,], type="p", ylim=c(0.15,0.85), cex.axis=0.75, pch=20, cex=0.5, ylab="",xlab="",main="",xaxt="n")	
for (i in dists){	
	color = "gray"
	ld <- 1
	if (i %in% c(25,40,120)){color <- "red"; ld <- 2}
	lines(c(i,i),c(z$lo[i], z$hi[i]), col=color, lwd=ld)
}	
lines(c(-100,1000), c(0.5,0.5), lty="dashed")
title("Electoral Bias in Simulated Florida Districting Plans\n(Compact District Simulation Procedure)",
, ylab="Average Share of Simulated Districts Favoring Bush (Nov. 2000)"
, xlab="Number of Districts in Simulated Districting Plan"
, cex.main=0.75
, cex.lab=0.75
, mgp=c(1.9, 0.5, 0))
axis(1, at=c(1,25,50,75,100,125,150,175,200), lab=c(1,25,50,75,100,125,150,175,200),
mgp=c(1.8, 1, 0), cex.axis=0.75)
points(repshare~dists  ,data=z[z$dists>=2 & z$dists<200,], type="p", pch=20, cex=0.5)




