##################################################################################
######## SECTION 1: THIS SECTION DOWNLOADS ALL REPLICATION DATA ONTO A LOCAL FOLDER
##################################################################################

dir <- paste(getwd(), "/Chen_Replication_Code",sep="")
dir.create(dir)
print(paste("ALL REPLICATION DATA WILL BE DOWNLOADED TO THE FOLLOWING FOLDER:",dir))

NonCompactFolder <- paste(dir, "/FL_Simulations_NonCompact",sep="")
FL40Shapefile <- paste(NonCompactFolder,"/FL40.shp",sep="")

if (!file.exists(FL40Shapefile)){
	NonCompactzipfile <- "http://www.umich.edu/~jowei/UnintentionalGerrymandering/FL_Simulations_NonCompact.zip"
	LocalNoncompactZipped <- paste(dir,"/FL_Simulations_NonCompact.zip",sep="")
	download.file(NonCompactzipfile, LocalNoncompactZipped )
	unzip(LocalNoncompactZipped, exdir=dir)
}
######## DOWNLOADING OF REPLICATION DATA ENDS HERE


#####################################################################
######## SECTION 2: REPLICATION CODE FOR FIGURE 5
#####################################################################

##REQUIRED LIBRARIES
library(maptools)
library(plotrix)
library(gpclib)
gpclibPermit()


############### GET COMPACT PLAN
dist <- 40
st <- "FL"
districts <- dist
x <- readShapePoly(paste(NonCompactFolder,"/",st,districts,".shp",sep=""))

proj4string(x) <- "+proj=longlat +datum=WGS84"
plans <- dim(x)[2]-15 ##TOTAL NUMBER OF SIMULATED PLANS

z <- sapply(slot(x, "polygons"), slot, "area")
areas <- 65755 * (z/sum(z))  ##AREA OF PRECINCTS IN SQUARE MILES (FLORIDA'S TOTAL AREA IS 65755 SQ MILES)
x$area <- areas
x$density <- x$TotPop/x$area
x$votes <- x$mccain+x$obama
summary(x$Pshares)



##postscript(paste(dir,"/Figure_5.eps",sep=""), width=9, height=3, horizontal=FALSE)

layout(   matrix(c(1,2,3), 1,3,byrow=TRUE), widths=c(1,1,1) )
## par(mar=c(2,0,2,0))


plot(I(Pshares)~repshare, main="Rural Precincts:\n(Under 500 Voters per Sq. Mile)", cex.main=1.5
 , ylab="Average Partisanship of the Precinct's\nAssigned District (Bush Vote Share)", xlab="Partisanship of Precinct\n(November '00 Bush Vote Share)", xlim=c(0,1), ylim=c(0.25, 0.7)
 ,data=x[x$votes>10 & x$density<500,], mgp=c(2.5,0.6,0), pch=20, cex.lab=0.85, cex.main=0.95, cex=0.9)
lines(c(0,1),c(0.5,0.5), col="blue", lwd=1)
lines(c(0.5,0.5),c(0,1), col="blue", lwd=1)


plot(I(Pshares)~repshare, main="Suburban and Town Precincts:\n(500 to 2,000 Voters per Sq. Mile)", cex.main=1.5
 , ylab="Average Partisanship of the Precinct's\nAssigned District (Bush Vote Share)", xlab="Partisanship of Precinct\n(November '00 Bush Vote Share)", xlim=c(0,1), ylim=c(0.25, 0.7)
 ,data=x[x$votes>10 & x$density>=500 & x$density<2000,], mgp=c(2.5,0.6,0), pch=20, cex.lab=0.85, cex.main=0.95, cex=0.9)
lines(c(0,1),c(0.5,0.5), col="blue", lwd=1)
lines(c(0.5,0.5),c(0,1), col="blue", lwd=1)


plot(I(Pshares)~repshare, main="Urban Precincts:\n(Over 2,000 Voters per Sq. Mile)", cex.main=1.5
 , ylab="Average Partisanship of the Precinct's\nAssigned District (Bush Vote Share)", xlab="Partisanship of Precinct\n(November '00 Bush Vote Share)", xlim=c(0,1), ylim=c(0.25, 0.7)
 ,data=x[x$votes>10 & x$density>=2000,], mgp=c(2.5,0.6,0), pch=20, cex.lab=0.85, cex.main=0.95, cex=0.9)
lines(c(0,1),c(0.5,0.5), col="blue", lwd=1)
lines(c(0.5,0.5),c(0,1), col="blue", lwd=1)

##dev.off()



