##################################################################################
######## SECTION 1: THIS SECTION DOWNLOADS ALL REPLICATION DATA ONTO A LOCAL FOLDER
##################################################################################

dir <- paste(getwd(), "/Chen_Replication_Code",sep="")
dir.create(dir)
print(paste("ALL REPLICATION DATA WILL BE DOWNLOADED TO THE FOLLOWING FOLDER:",dir))

##DOWNLOAD THE REPLICATION DATA FOR NON-COMPACT SIMULATIONS, IF NECESSARY
NonCompactFolder <- paste(dir, "/FL_Simulations_NonCompact",sep="")
FLdbffile <- paste(NonCompactFolder,"/FL.dbf",sep="")
if (!file.exists(FLdbffile)){
	NonCompactzipfile <- "http://www.umich.edu/~jowei/UnintentionalGerrymandering/FL_Simulations_NonCompact.zip"
	LocalNoncompactZipped <- paste(dir,"/FL_Simulations_NonCompact.zip",sep="")
	download.file(NonCompactzipfile, LocalNoncompactZipped )
	unzip(LocalNoncompactZipped, exdir=dir)
}

######## DOWNLOADING OF REPLICATION DATA ENDS HERE


#####################################################################
######## SECTION 2: CREATE THE ELECTORAL BIAS FILE
#####################################################################


st <- "FL"
library(foreign)

dists <- seq(1:200)
y <- as.data.frame(dists)
y$repshare <- NA
y$lo <- NA
y$hi <- NA

dbffile <- paste(NonCompactFolder,"/",st,".dbf",sep="")
dbf <- read.dbf(dbffile)
swrepvote <- sum(dbf$mccain, na.rm=TRUE) / (sum(dbf$mccain, na.rm=TRUE) + sum(dbf$obama, na.rm=TRUE))
BushVoteShare <- swrepvote


i <- 25
sharesfile <- paste(NonCompactFolder,"/",i,".txt",sep="")


x <- read.table(sharesfile)##[1:25,]
x1 <- x[,4:dim(x)[2]]

repseats <- apply(x1, 1, function(x) sum(x>BushVoteShare))

medians <- apply(x1, 1, function(x) median(x))

AvgRepSeats <- mean(repseats)
AvgRepSeatShare <- AvgRepSeats/i
NumberOfSimulations <- dim(x)[1]

y$repshare[i] <- AvgRepSeatShare
y$lo[i] <- min(repseats/i)
y$hi[i] <- max(repseats/i)

##output <- cbind(st, d, AvgRepSeats, AvgRepSeatShare, NumberOfSimulations, McCainVoteShare)

sim <- 1:length(repseats)
w <- as.data.frame(cbind(sim,repseats, medians))

w <- w[1:100,]

hp <- read.delim("http://www.umich.edu/~jowei/UnintentionalGerrymandering/SenatePlans/ProposedCDPlans.txt", header=T)
hpr <- hp[hp$Party=="R",]
hpd <- hp[hp$Party=="D",]


#############################################################
#############################################################
### HISTOGRAM FIGURE, HALF HORIZONTAL

##postscript(paste(dir,"/HistogramCD.eps",sep=""),height=8,width=8,horizontal=FALSE)

xl <- c(12,19)
lm <- 9
layout(   matrix(c(1,2), 2,1,byrow=TRUE), heights=c(1.5,2) )

par(mar=c(0,lm,0,0.1))	

##top plot of proposed plans
plot(rep(0,dim(w)[1])~w$repseats, xlim=xl, ylim=c(0.7,4.5), type="n",bty="n", ylab="Proposed and Enacted Plans",xlab="", xaxt="n", yaxt="n"
,mgp=c(lm-0.9, 1.70, 0)
)

axis(2,at=c(1,2,3,4), las=2,labels=c("Final Enacted \nDistricting Plan","Common Cause\nand LWV-\nProposed Plan","Republican-\nProposed Plans","Democrat-\nProposed Plans")
, mgp=c(2.5, 1.70, 0), cex.axis=1)

text(hpd$mrseats, rep(4,dim(hpr)[1])+runif(dim(hpr)[1],-0.4,0.4), labels="D", col="blue", cex=1.4,font=1)
text(hpr$mrseats, rep(3,dim(hpr)[1])+runif(dim(hpr)[1],-0.4,0.4), labels="R", col="red", cex=1.4,font=1)
text(16, 2, labels="C", col="green", cex=1.4,font=1)
text(17, 1, labels="E", col="black", cex=1.4,font=1)
lines(c(12.5,12.5),c(-100,100),lty="dashed")


par(mar=c(5.5,lm,0,0.1))	

plot(rep(0,dim(w)[1])~w$repseats, xlim=xl, ylim=c(0,40), type="n",bty="n", ylab="Frequency Among\nSimulated Districting Plans", xaxt="n", yaxt="n",xlab="")
title(xlab="Number of Bush-Leaning Districts\n(Out of 25 Total Congressional Districts)", mgp=c(4.25, 1.70, 0))

axis(1,at=seq(1:25),labels=paste(seq(1:25),"\n(", seq(1:25)/0.25 ,"%)",sep="") 
, mgp=c(2.5, 1.70, 0), cex.axis=0.79)

axis(2,at=c(0,10,20,30,40),labels=c(0,10,20,30,40) 
, mgp=c(2.5, 1.70, 0), cex.axis=1)

z <- summary(as.factor(w$repseats))
t <- 0.25
for (i in 1:5){
	s <- as.numeric(names(z)[i])
	rect(s-t,0,s+t, as.numeric(z[i]) )
}
lines(c(12.5,12.5),c(-100,100),lty="dashed")

##dev.off()


