##################################################################################
######## SECTION 1: THIS SECTION DOWNLOADS ALL REPLICATION DATA ONTO A LOCAL FOLDER
##################################################################################

dir <- paste(getwd(), "/Chen_Replication_Code",sep="")
dir.create(dir)
print(paste("ALL REPLICATION DATA WILL BE DOWNLOADED TO THE FOLLOWING FOLDER:",dir))

CrossStateFolder <- paste(dir, "/CrossState",sep="")
GAdbffile <- paste(CrossStateFolder,"/GA/GA.dbf",sep="")

if (!file.exists(GAdbffile)){
	CrossStatefile <- "http://www.umich.edu/~jowei/UnintentionalGerrymandering/CrossState.zip"
	LocalCrossStateZipped <- paste(dir,"/CrossState.zip",sep="")
	download.file(CrossStatefile , LocalCrossStateZipped )
	unzip(LocalCrossStateZipped, exdir=dir)
}
######## DOWNLOADING OF REPLICATION DATA ENDS HERE


#####################################################################
######## SECTION 2: CREATE THE ELECTORAL BIAS FILE
#####################################################################

CrossStateFolder <- paste(dir, "/CrossState",sep="")
biasfile <- paste(CrossStateFolder,"/electoralbias2000.txt",sep="")

file.remove(biasfile)
x <- read.delim(paste(CrossStateFolder,"/files.txt",sep=""))


library(foreign)

STchamber <- function(st, d, type){
Chamber <- type
CrossStateFolder <- paste(dir, "/CrossState",sep="")
biasfile <- paste(CrossStateFolder,"/electoralbias2000.txt",sep="")

folder <- paste(CrossStateFolder,"/",st,sep="")
dbffile <- paste(folder,"/",st,".dbf",sep="")

sharesfile <- paste(folder,"/",d,".txt",sep="")

if (file.exists(sharesfile) & d>1){

dbf <- read.dbf(dbffile)
swrepvote <- sum(dbf$mccain, na.rm=TRUE) / (sum(dbf$mccain, na.rm=TRUE) + sum(dbf$obama, na.rm=TRUE))
McCainVoteShare <- swrepvote

x <- read.table(sharesfile)
x1 <- x[,4:dim(x)[2]]

repseats <- apply(x1, 1, function(x) sum(x>swrepvote))
AvgRepSeats <- mean(repseats)
AvgRepSeatShare <- AvgRepSeats/d

repseatsRAW <- apply(x1, 1, function(x) sum(x>0.5))
AvgRepSeatsRAW <- mean(repseats)
AvgRepSeatShareRAW <- AvgRepSeats/d

NumberOfSimulations <- dim(x)[1]

##now get actual districts' bias
chamb <- "cong"
if (type=="SLDL"){chamb <- "h"}
if (type=="SLDU"){chamb <- "s"}


##now get my calculations of bias
dfile <- paste(CrossStateFolder,"/District2002BushGore/",st,"_",type,".txt",sep="")
dvotes <- read.delim(dfile)
mybias02 <- sum(dvotes$repshare>McCainVoteShare)/dim(dvotes)[1]
mydistricts02 <- dim(dvotes)[1]

mybias00 <- NA
mydistricts00 <- NA
dfile <- paste(CrossStateFolder,"/District2000BushGore/",st,"_",type,".txt",sep="")
if (file.exists(dfile)){
	dvotes <- read.delim(dfile)
	mybias00 <- sum(dvotes$repshare>McCainVoteShare)/dim(dvotes)[1]
	mydistricts00 <- dim(dvotes)[1]
}

output <- cbind(st, Chamber,d, AvgRepSeats, AvgRepSeatShare, AvgRepSeatsRAW, AvgRepSeatShareRAW, NumberOfSimulations, McCainVoteShare,
mybias00,mybias02, mydistricts00,mydistricts02
)


}else{output <- t(cbind(c(st, Chamber,d, rep(NA,10))))}

print(output)
write.table(as.data.frame(output), biasfile, row.names=F, col.names=(!file.exists(biasfile)), append=file.exists(biasfile), sep="\t")

##plot(ActDshare ~ Pshares, data=z)
return(NA)
}



##CALCULATE SIMULATED AND ACTUAL ELECTORAL BIAS FOR EACH STATE'S LEGISLATIVE CHAMBERS AND CONGRESSIONAL DELEGATION
for (i in 1:dim(x)[1]){
	st <- as.character(x$State[i])
	STchamber(st,x$congress[i],"CD")
	STchamber(st,x$senate[i],"SLDU")
	STchamber(st,x$house[i],"SLDL")
}



############################################################################## 
########## CODE TO CALCULATE COEFFICIENTS FOR EACH STATE
############################################################################## 

library(foreign)

x <- read.dta("http://www.umich.edu/~jowei/UnintentionalGerrymandering/bg_density_dem.dta")
states <- unique(x$state)
w_bg_dens_dem_coef <- NA

for (i in 1:length(states)){
	s <- state[i]
	xs <- x[x$state==s,]
	su <- summary(lm(dem_share~density_ln, weights=tot_pop  ,data=xs))
	w_bg_dens_dem_coef[i] <- su$coefficients[2,1]
}
y <- as.data.frame(cbind(state, w_bg_dens_dem_coef))
z <- read.delim(paste(CrossStateFolder,"/statepop.txt",sep=""))
y$st <- z$st[match(y$state, z$STATE)]
y$st[y$state=="Hawaii"] <- "HI"


##############################################################################
########## CODE TO PRODUCE FIGURE 7 (LEFT AD RIGHT PLOTS)
##############################################################################

b <- read.delim(biasfile)
library(foreign)

b$coef <- as.numeric(as.character(y$w_bg_dens_dem_coef[match(b$st, y$st)]))

bc <- b[b$Chamber=="CD",]
bu <- b[b$Chamber=="SLDU",]
bl <- b[b$Chamber=="SLDL",]
blu <- b[b$Chamber %in% c("SLDU","SLDL"),]
bs <- blu






##postscript(paste(dir,"/Figure7a.eps",sep=""), horizontal=FALSE, width=6, height=6)

##FIGURE 7 (LEFT): PLOTTING SIMULATED ELECTORAL BIAS AGAINST JONATHAN'S DEMOCRATIC-DENSITY COEFFICIENT
plot(AvgRepSeatShare~coef, type="n", data=bs, mgp=c(3.3, 0.55, 0), xlim=c(-0.01,0.08), ylim=c(0.40,0.67), main="",xlab="",ylab="")
text(bu$coef, bu$AvgRepSeatShare, bu$st,col="red", cex=1)
text(bl$coef, bl$AvgRepSeatShare, bl$st,col="blue", cex=1)
m <- lm(AvgRepSeatShare~coef, data=bs)
summary(m)
abline(m)
title("Simulated Electoral Bias and the \nUrban Concentration of Democrats", ylab="Average Simulated Republican Seat Share", 
	xlab="Coefficient of Regressing County-Level \nDemocratic Vote Share onto Population Density", mgp=c(3.0, 0.3, 0), cex.lab=1.3, cex.main=1.3)

text(0.06,0.425,"Legend:", col="black", pos=4, font=2)
text(0.06,0.41,"State Senate", col="red", pos=4)
text(0.06,0.40,"State House", col="blue", pos=4)
##dev.off()




##civil war population change figure:
x <- read.delim(paste(CrossStateFolder,"/statepop.txt",sep=""))

x$X1890del1950 <- x$total1950 - x$total1890
b$delpop <- (x$delurbanprop[match(b$st, x$st)])


##b$yvar <- b$mybias02
b$yvar <- b$AvgRepSeatShare
bc <- b[b$Chamber=="CD",]
bu <- b[b$Chamber=="SLDU",]
bl <- b[b$Chamber=="SLDL",]
blu <- b[b$Chamber %in% c("SLDU","SLDL"),]


##postscript(paste(dir,"/Figure7b.eps",sep=""), horizontal=FALSE, width=6, height=6)
bs <- blu

##FIGURE 7 (RIGHT) PLOTTING SIMULATED ELECTORAL BIAS AGAINST CHANGE IN URBAN POPULATION PROPORTION
dev.new()
plot(yvar~delpop, type="n", data=bs, mgp=c(3.3, 0.55, 0), ylim=c(0.43,0.67), main="",xlab="",ylab="")
text(bl$delpop, bl$yvar, bl$st,col="blue", cex=1)
text(bu$delpop, bu$yvar, bu$st,col="red", cex=1)
m <- lm(yvar~delpop, data=bs)
summary(m)
abline(m)
title("Simulated Electoral Bias and \nUrban Population Growth", ylab="Average Simulated Republican Seat Share", 
	xlab="Urban Population Percentage in 2000 \nMinus Urban Population Percentage in 1950", mgp=c(3.0, 0.3, 0), cex.lab=1.3, cex.main=1.3)

text(0.21,0.455,"Legend:", col="black", pos=4, font=2)
text(0.21,0.44,"State Senate", col="red", pos=4)
text(0.21,0.43,"State House", col="blue", pos=4)
##dev.off()

