##################################################################################
######## SECTION 1: THIS SECTION DOWNLOADS ALL REPLICATION DATA ONTO A LOCAL FOLDER
##################################################################################

dir <- paste(getwd(), "/Chen_Replication_Code",sep="")
dir.create(dir)
print(paste("ALL REPLICATION DATA WILL BE DOWNLOADED TO THE FOLLOWING FOLDER:",dir))

CrossStateFolder <- paste(dir, "/CrossState",sep="")
GAdbffile <- paste(CrossStateFolder,"/GA/GA.dbf",sep="")
if (!file.exists(GAdbffile)){
	CrossStatefile <- "http://www.umich.edu/~jowei/UnintentionalGerrymandering/CrossState.zip"
	LocalCrossStateZipped <- paste(dir,"/CrossState.zip",sep="")
	download.file(CrossStatefile , LocalCrossStateZipped )
	unzip(LocalCrossStateZipped, exdir=dir)
}

######## DOWNLOADING OF REPLICATION DATA ENDS HERE


#####################################################################
######## SECTION 2: CREATE THE ELECTORAL BIAS FILE
#####################################################################

CrossStateFolder <- paste(dir, "/CrossState",sep="")
biasfile <- paste(CrossStateFolder,"/electoralbias2000.txt",sep="")

file.remove(biasfile)
x <- read.delim(paste(CrossStateFolder,"/files.txt",sep=""))


library(foreign)

STchamber <- function(st, d, type){
Chamber <- type
CrossStateFolder <- paste(dir, "/CrossState",sep="")
biasfile <- paste(CrossStateFolder,"/electoralbias2000.txt",sep="")

folder <- paste(CrossStateFolder,"/",st,sep="")
dbffile <- paste(folder,"/",st,".dbf",sep="")

sharesfile <- paste(folder,"/",d,".txt",sep="")

if (file.exists(sharesfile) & d>1){

dbf <- read.dbf(dbffile)
swrepvote <- sum(dbf$mccain, na.rm=TRUE) / (sum(dbf$mccain, na.rm=TRUE) + sum(dbf$obama, na.rm=TRUE))
McCainVoteShare <- swrepvote

x <- read.table(sharesfile)
x1 <- x[,4:dim(x)[2]]

repseats <- apply(x1, 1, function(x) sum(x>swrepvote))
AvgRepSeats <- mean(repseats)
AvgRepSeatShare <- AvgRepSeats/d

repseatsRAW <- apply(x1, 1, function(x) sum(x>0.5))
AvgRepSeatsRAW <- mean(repseats)
AvgRepSeatShareRAW <- AvgRepSeats/d

NumberOfSimulations <- dim(x)[1]

##now get actual districts' bias
chamb <- "cong"
if (type=="SLDL"){chamb <- "h"}
if (type=="SLDU"){chamb <- "s"}


##now get my calculations of bias
dfile <- paste(CrossStateFolder,"/District2002BushGore/",st,"_",type,".txt",sep="")
dvotes <- read.delim(dfile)
mybias02 <- sum(dvotes$repshare>McCainVoteShare)/dim(dvotes)[1]
mydistricts02 <- dim(dvotes)[1]

mybias00 <- NA
mydistricts00 <- NA
dfile <- paste(CrossStateFolder,"/District2000BushGore/",st,"_",type,".txt",sep="")
if (file.exists(dfile)){
	dvotes <- read.delim(dfile)
	mybias00 <- sum(dvotes$repshare>McCainVoteShare)/dim(dvotes)[1]
	mydistricts00 <- dim(dvotes)[1]
}

output <- cbind(st, Chamber,d, AvgRepSeats, AvgRepSeatShare, AvgRepSeatsRAW, AvgRepSeatShareRAW, NumberOfSimulations, McCainVoteShare,
mybias00,mybias02, mydistricts00,mydistricts02
)


}else{output <- t(cbind(c(st, Chamber,d, rep(NA,10))))}

print(output)
write.table(as.data.frame(output), biasfile, row.names=F, col.names=(!file.exists(biasfile)), append=file.exists(biasfile), sep="\t")

##plot(ActDshare ~ Pshares, data=z)
return(NA)
}



##CALCULATE SIMULATED AND ACTUAL ELECTORAL BIAS FOR EACH STATE'S LEGISLATIVE CHAMBERS AND CONGRESSIONAL DELEGATION
for (i in 1:dim(x)[1]){
	st <- as.character(x$State[i])
	STchamber(st,x$congress[i],"CD")
	STchamber(st,x$senate[i],"SLDU")
	STchamber(st,x$house[i],"SLDL")
}



######################################################################
##### NOW CREATE FIGURE 8 (left and right plots)
######################################################################

b <- read.delim(biasfile)


## CREATE LEFT PLOT IN FIGURE 8
##postscript(paste(dir,"/Figure8a.eps",sep=""), horizontal=FALSE, width=6, height=6)
##YEAR 2000 DISTRICTS
bs <- b[b$Chamber!="CD" & b$mydistricts00==b$d,]
bsu <- bs[bs$Chamber=="SLDU",]
bsl <- bs[bs$Chamber=="SLDL",]

plot(mybias00 ~ AvgRepSeatShare, data=bs, type="n", xlim=c(0.42,0.67), ylim=c(0.42,0.67), main="",xlab="",ylab="")
lines(c(-1,1),c(-1,1), lty=2)
##text(bsu$mybias00, bsu$AvgRepSeatShare, labels=bsu$st ,col="red", cex=0.8)
text(bsu$AvgRepSeatShare, bsu$mybias00, labels=bsu$st ,col="red", cex=0.8)

title("Electoral Bias in State Legislatures,\nPre-2002 Districts", xlab="Mean Republican Seat Share in Simulations", 
	ylab="Republican Seat Share, Actual Pre-2002 Districts", mgp=c(2.3, 0.5, 0), cex.lab=1.3, cex.main=1.3)
text(0.61,0.455,"Legend:", col="black", pos=4, font=2)
text(0.61,0.44,"State Senate", col="red", pos=4)
text(0.61,0.43,"State House", col="blue", pos=4)
rect(0.61,0.42,0.68,0.465, lwd=1)
text(bsl$AvgRepSeatShare, bsl$mybias00, labels=bsl$st, col="blue", cex=0.8)

##dev.off()




## CREATE RIGHT PLOT IN FIGURE 8
##postscript(paste(dir,"/Figure8b.eps",sep=""), horizontal=FALSE, width=6, height=6)
##YEAR 2002 DISTRICTS
bs <- b[b$Chamber!="CD" & b$mydistricts02==b$d,]
bsu <- bs[bs$Chamber=="SLDU",]
bsl <- bs[bs$Chamber=="SLDL",]
bsc <- b[b$Chamber=="CD",]

dev.new()
plot(mybias02 ~ AvgRepSeatShare, data=bs, type="n", xlim=c(0.42,0.67), ylim=c(0.42,0.67), main="",xlab="",ylab="")
lines(c(-1,1),c(-1,1), lty=2)
text(bsu$AvgRepSeatShare, bsu$mybias02, labels=bsu$st ,col="red", cex=0.8)
title("Electoral Bias in State Legislatures,\nPost-2002 Districts", xlab="Mean Republican Seat Share in Simulations", 
	ylab="Republican Seat Share, Actual Post-2002 Districts", mgp=c(2.3, 0.5, 0), cex.lab=1.3, cex.main=1.3)
text(0.61,0.455,"Legend:", col="black", pos=4, font=2)
text(0.61,0.44,"State Senate", col="red", pos=4)
text(0.61,0.43,"State House", col="blue", pos=4)
rect(0.61,0.42,0.68,0.465, lwd=1)
text(bsl$AvgRepSeatShare, bsl$mybias02, labels=bsl$st, col="blue", cex=0.8)

##dev.off()
