##################################################################################
######## SECTION 1: THIS SECTION DOWNLOADS ALL REPLICATION DATA ONTO A LOCAL FOLDER
##################################################################################

dir <- paste(getwd(), "/Chen_Replication_Code",sep="")
dir.create(dir)
print(paste("ALL REPLICATION DATA WILL BE DOWNLOADED TO THE FOLLOWING FOLDER:",dir))

##DOWNLOAD THE REPLICATION DATA FOR NON-COMPACT SIMULATIONS, IF NECESSARY
NonCompactFolder <- paste(dir, "/FL_Simulations_NonCompact",sep="")
FLdbffile <- paste(NonCompactFolder,"/FL.dbf",sep="")
if (!file.exists(FLdbffile)){
	NonCompactzipfile <- "http://www.umich.edu/~jowei/UnintentionalGerrymandering/FL_Simulations_NonCompact.zip"
	LocalNoncompactZipped <- paste(dir,"/FL_Simulations_NonCompact.zip",sep="")
	download.file(NonCompactzipfile, LocalNoncompactZipped )
	unzip(LocalNoncompactZipped, exdir=dir)
}

######## DOWNLOADING OF REPLICATION DATA ENDS HERE




st <- "FL"
library(foreign)
i <- 40


#####################################################################
######## SECTION 2: GET NON-COMPACT SIMULATIONS
#####################################################################

dbffile <- paste(NonCompactFolder,"/",st,".dbf",sep="")
dbf <- read.dbf(dbffile)
swrepvote <- sum(dbf$mccain, na.rm=TRUE) / (sum(dbf$mccain, na.rm=TRUE) + sum(dbf$obama, na.rm=TRUE))
BushVoteShare <- swrepvote
sharesfile <- paste(NonCompactFolder,"/",i,".txt",sep="")
##sharesfile <- paste("C:/Research/Dropbox/SimulationsNoncompact/FL/2000vote/plans","/",i,".txt",sep="")
x <- read.table(sharesfile)
x1 <- x[,4:dim(x)[2]]
repseats <- apply(x1, 1, function(x) sum(x>BushVoteShare))
medians <- apply(x1, 1, function(x) median(x))
sim <- 1:length(repseats)
w <- as.data.frame(cbind(sim,repseats, medians))
w <- w[1:100,]


#####################################################################
######## SECTION 3: GET COMPACT SIMULATIONS
#####################################################################
CompactFolder <- paste(dir, "/FL_Simulations_Compact",sep="")
i <- 40

dbffile <- paste(CompactFolder,"/",st,".dbf",sep="")
dbf <- read.dbf(dbffile)
swrepvote <- sum(dbf$mccain, na.rm=TRUE) / (sum(dbf$mccain, na.rm=TRUE) + sum(dbf$obama, na.rm=TRUE))
BushVoteShare <- swrepvote
sharesfile <- paste(CompactFolder,"/",i,".txt",sep="")
##sharesfile <- paste("C:/Research/Dropbox/SimulationsNoncompact/FL/2000vote/plans","/",i,".txt",sep="")
x <- read.table(sharesfile)
x1 <- x[,4:dim(x)[2]]
repseats <- apply(x1, 1, function(x) sum(x>BushVoteShare))
medians <- apply(x1, 1, function(x) median(x))
sim <- 1:length(repseats)
w2 <- as.data.frame(cbind(sim,repseats, medians))
w2 <- w2[1:100,]


summary(as.factor(repseats))

#############################################################
#############################################################
### HISTOGRAM FIGURE, HALF HORIZONTAL

##postscript(paste(dir,"/HistogramCD.eps",sep=""),height=8,width=8,horizontal=FALSE)

xl <- c(20,30)
lm <- 9
layout(   matrix(c(1,2), 2,1,byrow=TRUE), heights=c(1,1) )


##PLOT THE NON-COMPACT SIMULATIONS
par(mar=c(5.5,lm,0,0.1))	

plot(rep(0,dim(w)[1])~w$repseats, xlim=xl, ylim=c(0,40), type="n",bty="n", ylab="Frequency Among\nSimulated Districting Plans", xaxt="n", yaxt="n",xlab="")
title(xlab="Number of Bush-Leaning Districts\n(Out of 25 Total Congressional Districts)", mgp=c(4.25, 1.70, 0))

axis(1,at=seq(1:25),labels=paste(seq(1:25),"\n(", seq(1:25)/0.25 ,"%)",sep="") 
, mgp=c(2.5, 1.70, 0), cex.axis=0.79)

axis(2,at=c(0,10,20,30,40),labels=c(0,10,20,30,40) 
, mgp=c(2.5, 1.70, 0), cex.axis=1)

z <- summary(as.factor(w$repseats))
t <- 0.25
for (i in 1:length(names(z))){
	s <- as.numeric(names(z)[i])
	rect(s-t,0,s+t, as.numeric(z[i]) )
}
lines(c(12.5,12.5),c(-100,100),lty="dashed")



##PLOT THE COMPACT SIMULATIONS
par(mar=c(5.5,lm,0,0.1))	

plot(rep(0,dim(w2)[1])~w2$repseats, xlim=xl, ylim=c(0,40), type="n",bty="n", ylab="Frequency Among\nSimulated Districting Plans", xaxt="n", yaxt="n",xlab="")
title(xlab="Number of Bush-Leaning Districts\n(Out of 25 Total Congressional Districts)", mgp=c(4.25, 1.70, 0))

axis(1,at=seq(1:25),labels=paste(seq(1:25),"\n(", seq(1:25)/0.25 ,"%)",sep="") 
, mgp=c(2.5, 1.70, 0), cex.axis=0.79)

axis(2,at=c(0,10,20,30,40),labels=c(0,10,20,30,40) 
, mgp=c(2.5, 1.70, 0), cex.axis=1)

z <- summary(as.factor(w2$repseats))
t <- 0.25
for (i in 1:length(names(z))){
	s <- as.numeric(names(z)[i])
	rect(s-t,0,s+t, as.numeric(z[i]) )
}
lines(c(12.5,12.5),c(-100,100),lty="dashed")


##dev.off()

summary(as.factor(repseats))















#############################################################
#############################################################
### HISTOGRAM FIGURE, HALF HORIZONTAL

##postscript(paste(dir,"/HistogramCD.eps",sep=""),height=8,width=8,horizontal=FALSE)

xl <- c(12,19)
lm <- 9
layout(   matrix(c(1,2), 2,1,byrow=TRUE), heights=c(1.5,2) )






hp <- read.delim("http://www.umich.edu/~jowei/UnintentionalGerrymandering/SenatePlans/ProposedCDPlans.txt", header=T)
hpr <- hp[hp$Party=="R",]
hpd <- hp[hp$Party=="D",]

